package Catmandu::Fix::Date;
# ABSTRACT: Catmandu fixes for processing dates
our $VERSION = "0.0122";

=head1 NAME

  Catmandu::Fix::Date - Catmandu fixes for processing dates

=head1 AUTHOR

Nicolas Franck, C<< <nicolas.franck at ugent.be> >>

=head1 SYNOPSIS

  For documentation on these fixes see:

    L<Catmandu::Fix::datetime_format>
    L<Catmandu::Fix::timestamp>
    L<Catmandu::Fix::start_day>
    L<Catmandu::Fix::end_day>
    L<Catmandu::Fix::start_week>
    L<Catmandu::Fix::end_week>
    L<Catmandu::Fix::start_year>
    L<Catmandu::Fix::end_year>


=head1 SEE ALSO

  L<Catmandu::Fix>
  L<Catmandu>

=head1 LICENSE AND COPYRIGHT

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See L<http://dev.perl.org/licenses/> for more information.

=cut

1;
